@@ -1,6 +1,7 @@
 import abc
 import os
-from typing import Callable, Dict, Union
+import pathlib
+from typing import Callable, Dict, Optional, Union
 
 import matplotlib.pylab as plt
 import numpy as np
@@ -8,6 +9,8 @@ from numpy import float64, ndarray
 from scipy import interpolate
 from six import with_metaclass
 
+from modes.config import PATH
+
 StringOrNumber = Union[str, float, int]
 
 
@@ -249,49 +252,53 @@ class _AbstractStructure(with_metaclass(abc.ABCMeta)):
 
         return self.n
 
-    def write_to_file(self, filename="material_index.dat", plot=True):
-        """
-        Write the refractive index profile to file.
+    def write_to_file(
+        self, filename: str = "material_index.dat", dirpath: Optional[str] = None
+    ) -> None:
+        """Write the refractive index profile to file.
 
         Args:
-            filename (str): The nominal filename the refractive
+            filename: The nominal filename the refractive
                 index data should be saved to.
-            plot (bool): `True` if plots should be generates,
-                otherwise `False`.  Default is `True`.
+            dirpath: directory path to write the file.
         """
 
-        with open(filename, "w") as fs:
+        dirpath = dirpath or PATH.cache
+        filepath = pathlib.Path(dirpath) / filename
+
+        with open(filepath, "w") as fs:
             for n_row in np.abs(self.n[::-1]):
                 n_str = ",".join([str(v) for v in n_row])
                 fs.write(n_str + "\n")
 
-        if plot:
-            filename_image_prefix, _ = os.path.splitext(filename)
-            filename_image = filename_image_prefix + ".png"
-            args = {
-                "title": "Refractive Index Profile",
-                "x_pts": self.x_pts,
-                "y_pts": self.y_pts,
-                "x_min": self.x_min,
-                "x_max": self.x_max,
-                "y_min": self.y_min,
-                "y_max": self.y_max,
-                "filename_data": filename,
-                "filename_image": filename_image,
-            }
+    def plot(self, filename: str = "material_index.dat") -> None:
+        self.write_to_file(filename=filename)
+        filename_image_prefix, _ = os.path.splitext(filename)
+        filename_image = filename_image_prefix + ".png"
+        args = {
+            "title": "Refractive Index Profile",
+            "x_pts": self.x_pts,
+            "y_pts": self.y_pts,
+            "x_min": self.x_min,
+            "x_max": self.x_max,
+            "y_min": self.y_min,
+            "y_max": self.y_max,
+            "filename_data": filename,
+            "filename_image": filename_image,
+        }
 
-            heatmap = np.loadtxt(args["filename_data"], delimiter=",")
-            plt.clf()
-            plt.title(args["title"])
-            plt.xlabel("$x$")
-            plt.ylabel("$y$")
-            plt.imshow(
-                np.flipud(heatmap),
-                extent=(args["x_min"], args["x_max"], args["y_min"], args["y_max"]),
-                aspect="auto",
-            )
-            plt.colorbar()
-            plt.savefig(filename_image)
+        heatmap = np.loadtxt(args["filename_data"], delimiter=",")
+        plt.clf()
+        plt.title(args["title"])
+        plt.xlabel("$x$")
+        plt.ylabel("$y$")
+        plt.imshow(
+            np.flipud(heatmap),
+            extent=(args["x_min"], args["x_max"], args["y_min"], args["y_max"]),
+            aspect="auto",
+        )
+        plt.colorbar()
+        plt.savefig(filename_image)
 
     def __str__(self) -> str:
         return self.name
